using backend.Models.NswFuelApi;
using backend.Services;
using Microsoft.AspNetCore.Mvc;

namespace backend.Controllers;

[ApiController]
[Route("api/fuel-types")]
public class FuelTypeController : ControllerBase
{
    private readonly IFuelTypeService _fuelTypeService;
    private readonly ILogger<FuelTypeController> _logger;

    public FuelTypeController(IFuelTypeService fuelTypeService, ILogger<FuelTypeController> logger)
    {
        _fuelTypeService = fuelTypeService;
        _logger = logger;
    }

    [HttpGet("all")]
    [EndpointDescription("Retrieves a list of all available fuel types.")]
    [EndpointSummary("Get all fuel types")]
    public async Task<ActionResult<IEnumerable<FuelType>>> GetAllFuelTypes()
    {
        _logger.LogInformation("Processing api/fuel-types/all request");
        var fuelTypes = await _fuelTypeService.GetAllFuelTypes();
        if (!fuelTypes.Any()) return NoContent();

        return Ok(fuelTypes);
    }

    [HttpGet("common")]
    [EndpointDescription("Retrieves a list of the most common fuel types.")]
    [EndpointSummary("Get common fuel types")]
    public async Task<ActionResult<IEnumerable<FuelType>>> GetCommonFuelTypes()
    {
        _logger.LogInformation("Processing api/fuel-types/common request");
        var fuelTypes = await _fuelTypeService.GetCommonFuelTypes();
        if (!fuelTypes.Any()) return NoContent();

        return Ok(fuelTypes);
    }
}