using backend.Models.SuburbBoundariesApi;
using backend.Services;
using Microsoft.AspNetCore.Mvc;

namespace backend.Controllers;

[ApiController]
[Route("api/suburb-boundaries")]
public class SuburbBoundaryController : ControllerBase
{
    private readonly ILogger<SuburbBoundaryController> _logger;
    private readonly ISuburbBoundariesService _suburbBoundariesService;

    public SuburbBoundaryController(
        ISuburbBoundariesService suburbBoundariesService,
        ILogger<SuburbBoundaryController> logger)
    {
        _suburbBoundariesService = suburbBoundariesService;
        _logger = logger;
    }

    [HttpGet("suburbs/all")]
    [EndpointDescription("Retrieves a list of all of the suburbs available.")]
    [EndpointSummary("Get the ID and Name for every Suburb in the DB.")]
    public async Task<ActionResult<IEnumerable<Suburb>>> GetAllSuburbs()
    {
        _logger.LogInformation("Processing api/suburb-boundaries/suburbs/all request");
        var result = await _suburbBoundariesService.GetAllSuburbs();
        if (result == null) return NotFound("No Suburbs found.");

        return Ok(result);
    }

    [HttpGet("suburbs/by-name")]
    [EndpointDescription("Retrieves a list of all of the Suburbs that contain the name input.")]
    [EndpointSummary("Search for Suburbs in the DB by name")]
    public async Task<ActionResult<IEnumerable<Suburb>>> GetAllSuburbs([FromQuery] string name)
    {
        _logger.LogInformation("Processing api/suburb-boundaries/suburbs/by-name request");
        var result = await _suburbBoundariesService.GetSuburbsByName(name);
        if (result == null) return NotFound("No Suburbs found with the given name.");

        return Ok(result);
    }

    [HttpGet("by-id")]
    [EndpointDescription("Retrieves the single SuburbBoundary, which matches the input ID.")]
    [EndpointSummary("Return a single SuburbBoundary")]
    public async Task<ActionResult<SuburbBoundary?>> GetSuburbBoundaryById([FromQuery] string id)
    {
        _logger.LogInformation("Processing api/suburb-boundaries/by-id request");
        var result = await _suburbBoundariesService.GetSuburbBoundaryById(id);
        if (result == null) return NotFound("No suburb boundary found with the given ID.");

        return Ok(result);
    }
}