using System.Text.Json.Serialization;
using ServiceStack.DataAnnotations;

namespace backend.Models.NswFuelApi;

public class Station
{
    [PrimaryKey] public Guid Id { get; init; } = Guid.NewGuid();

    public string Brand { get; set; }

    public int Code { get; set; }

    public string Name { get; set; }

    public string Address { get; set; }

    public string Geography { get; set; }

    public string State { get; set; }

    public DateTimeOffset CreatedAt { get; set; } = DateTimeOffset.UtcNow;

    public DateTimeOffset? DeletedAt { get; set; }

    //ignored property to use for showing distance to a station from a point
    [Ignore] public double? Distance { get; set; }

    //computed property to extract lat/long from Geography
    [Ignore]
    public NumericReferencePoint? Coordinates
    {
        get
        {
            if (string.IsNullOrWhiteSpace(Geography)) return null;

            try
            {
                var pointData = Geography.Split(';')[1].Replace("POINT(", "").Replace(")", "");
                var coordinates = pointData.Split(' ');
                var referencePoint = new NumericReferencePoint
                {
                    Latitude = double.Parse(coordinates[1]),
                    Longitude = double.Parse(coordinates[0])
                };
                return referencePoint;
            }
            catch
            {
                return null;
            }
        }
    }
}

public class StationWithDistance
{
    [PrimaryKey] public Guid Id { get; init; } = Guid.NewGuid();

    public string Brand { get; set; }

    public int Code { get; set; }

    public string Name { get; set; }

    public string Address { get; set; }

    public string Geography { get; set; }

    public string State { get; set; }

    public DateTimeOffset CreatedAt { get; set; } = DateTimeOffset.UtcNow;

    public double? Distance { get; set; }

    //computed property to extract lat/long from Geography
    [Ignore]
    public NumericReferencePoint? Coordinates
    {
        get
        {
            if (string.IsNullOrWhiteSpace(Geography)) return null;

            try
            {
                var pointData = Geography.Split(';')[1].Replace("POINT(", "").Replace(")", "");
                var coordinates = pointData.Split(' ');
                var referencePoint = new NumericReferencePoint
                {
                    Latitude = double.Parse(coordinates[1]),
                    Longitude = double.Parse(coordinates[0])
                };
                return referencePoint;
            }
            catch
            {
                return null;
            }
        }
    }
}

public class StationDto
{
    [JsonPropertyName("brand")] public string Brand { get; set; }

    [JsonPropertyName("code")] public string Code { get; set; }

    [JsonPropertyName("name")] public string Name { get; set; }

    [JsonPropertyName("address")] public string Address { get; set; }

    [JsonPropertyName("location")] public Location Location { get; set; }

    [JsonPropertyName("state")] public string State { get; set; }
}