using backend.Models.NswFuelApi;
using ServiceStack.DataAnnotations;

namespace backend.Models.SuburbBoundariesApi;

public class SuburbBoundary
{
    [PrimaryKey] public Guid Id { get; init; } = Guid.NewGuid();

    public string? Name { get; set; }

    public string? Geometry { get; set; }

    public string? Centroid { get; set; }

    //computed property to extract lat/long from Centroid
    [Ignore]
    public NumericReferencePoint? CentroidCoordinates
    {
        get
        {
            if (string.IsNullOrWhiteSpace(Centroid)) return null;

            try
            {
                var pointData = Centroid.Replace("POINT(", "").Replace(")", "");
                var coordinates = pointData.Split(' ');
                var referencePoint = new NumericReferencePoint
                {
                    Latitude = double.Parse(coordinates[1]),
                    Longitude = double.Parse(coordinates[0])
                };
                return referencePoint;
            }
            catch
            {
                return null;
            }
        }
    }

    public DateTimeOffset? DtCreate { get; set; }

    public DateTimeOffset CreatedAt { get; set; } = DateTimeOffset.UtcNow;
}

public class Suburb
{
    public Guid Id { get; init; }

    public string? Name { get; set; }
}