using backend.Models.NswFuelApi;
using ServiceStack.Data;
using ServiceStack.OrmLite;

namespace backend.Services;

public class BrandService : IBrandService
{
    private readonly IDbConnectionFactory _dbConnectionFactory;

    public BrandService(IDbConnectionFactory dbConnectionFactory)
    {
        _dbConnectionFactory = dbConnectionFactory;
    }

    public async Task<IEnumerable<BrandType>> GetAllBrands()
    {
        using var db = _dbConnectionFactory.OpenDbConnection();
        var brands = await db.SelectAsync<BrandType>();
        return brands;
    }

    public async Task<IEnumerable<BrandType>> GetBrandsByState(string state)
    {
        using var db = _dbConnectionFactory.OpenDbConnection();
        var brands = await db.SelectAsync<BrandType>(x => x.State.ToLower().Contains(state.ToLower()));
        return brands;
    }

    public async Task<IEnumerable<BrandType>> GetBrandsByName(string name)
    {
        using var db = _dbConnectionFactory.OpenDbConnection();
        var brands =
            await db.SelectAsync<BrandType>(x => x.Name.ToLower().Contains(name.ToLower()));
        return brands;
    }
}