using Hangfire;

namespace backend.Services.Init;

public class HangfireInitialiser
{
    private readonly ILogger<HangfireInitialiser> _logger;
    private readonly IRecurringJobManager _recurringJobManager;

    public HangfireInitialiser(ILogger<HangfireInitialiser> logger, IRecurringJobManager recurringJobManager)
    {
        _logger = logger;
        _recurringJobManager = recurringJobManager;
    }

    public void RegisterFuelApiRefreshJobs()
    {
        _logger.LogInformation("Registering recurring jobs");

        //four-hourly refresh for reference data = 124/month max.
        _recurringJobManager.AddOrUpdate<INswFuelApiService>(
            "refresh_lovs",
            x => x.GetLovsAsync(),
            "0 */4 * * *");

        //twenty minute refresh for prices = 2,232/month max.
        _recurringJobManager.AddOrUpdate<INswFuelApiService>(
            "refresh_prices",
            x => x.GetCurrentPricesAsync(),
            "*/20 * * * *");

        //weekly refresh for suburb boundaries at midnight - do this in Sydney time (safe to assume the app will be run in NSW)
        _recurringJobManager.AddOrUpdate<ISuburbBoundariesService>(
            "fetch_suburb_boundaries",
            x => x.FetchFeatures(),
            "0 0 * * 0",
            new RecurringJobOptions
            {
                TimeZone = TimeZoneInfo.FindSystemTimeZoneById("Australia/Sydney")
            });

        _logger.LogInformation("Recurring jobs registered successfully");
    }

    public void InitialiseDataOnApplicationLaunch()
    {
        _logger.LogInformation("Trigerring Hangfire jobs for data initialisation");

        _recurringJobManager.Trigger("refresh_lovs");
        _recurringJobManager.Trigger("refresh_prices");
        _recurringJobManager.Trigger("fetch_suburb_boundaries");

        _logger.LogInformation("Finished triggering Hangfire initialisation jobs");
    }
}