"use client";

import { Badge, Card, Group, Text } from "@mantine/core";
import Image from "next/image";
import classes from "./BadgeCard.module.css";

type BadgeType = {
  emoji: string;
  label: string;
  colour?: string;
};

type BadgeCardProps = {
  image: string;
  imageDimensions?: { height?: number; width?: number };
  title: string;
  description: string;
  titleBadge: string;
  badges: BadgeType[];
  tagsDescription: string;
};

export function BadgeCard(props: BadgeCardProps) {
  const badges = props.badges.map((badge) => (
    <Badge
      variant="light"
      key={badge.label}
      leftSection={badge.emoji}
      color={badge?.colour}
    >
      {badge.label}
    </Badge>
  ));

  return (
    <Card withBorder radius="md" p="md" className={classes.card}>
      <Card.Section px={10} py={10}>
        <Image
          src={props.image}
          alt={props.title}
          height={props.imageDimensions?.height}
          width={props.imageDimensions?.width}
        />
      </Card.Section>

      <Card.Section className={classes.section} mt="md">
        <Group justify="apart">
          <Text fz="lg" fw={500}>
            {props.title}
          </Text>
          <Badge size="sm" variant="light">
            {props.titleBadge}
          </Badge>
        </Group>
        <Text fz="sm" mt="xs">
          {props.description}
        </Text>
      </Card.Section>

      <Card.Section className={classes.section}>
        <Text mt="md" className={classes.label} c="dimmed">
          {props.tagsDescription}
        </Text>
        <Group gap={7} mt={5}>
          {badges}
        </Group>
      </Card.Section>
    </Card>
  );
}
