import { Container, Group, Text } from "@mantine/core";
import Image from "next/image";
import Link from "next/link";
import { usePathname, useRouter } from "next/navigation";
import { useState } from "react";
import logo from "../../../../public/fuel-app-logo-lime.svg";
import classes from "./Footer.module.css";

const links = [
  { link: "/contact", label: "Contact" },
  { link: "/legal", label: "Legal" },
  { link: "/attribution", label: "Attribution" },
];

export default function Footer() {
  const pathName = usePathname();
  const [active, setActive] = useState(pathName);
  const router = useRouter();

  const navLinks = links.map((link) => (
    <Link
      key={link.label}
      href={link.link}
      className={classes.link}
      data-active={active === link.link || undefined}
      onClick={() => {
        setActive(link.link);
        router.push(link.link);
      }}
    >
      {link.label}
    </Link>
  ));

  return (
    <div className={classes.footer}>
      <Container className={classes.inner}>
        <Group>
          <Image src={logo} alt="logo" className={classes.logo} height={28} />
          <Text
            fz={28}
            variant="gradient"
            gradient={{ from: "lime.7", to: "green" }}
          >
            Fuel Wizard
          </Text>
        </Group>
        <Group className={classes.links}>{navLinks}</Group>
      </Container>
    </div>
  );
}
