"use client";

import { ReactNode } from "react";
import { MapContainer } from "react-leaflet";
import { SuburbBoundary } from "../../../generated";
import { Coordinate } from "../../../models/Coordinate";
import CustomMapContent from "./CustomMapContent";

export type CustomMapPoint = {
  lat: number;
  long: number;
  popup?: ReactNode;
};

export type CustomMapProps = {
  height?: number | string;
  width?: number | string;
  zoom?: number;
  scrollWheelZoom?: boolean;
  centre?: Coordinate;
  points?: CustomMapPoint[];
  clickToPlaceMarker?: boolean;
  onMarkerPlaced?: (coordinates: Coordinate) => void; //callback to pass coordinates up
  markerPosition?: Coordinate; //external marker position override
  suburbBoundary?: SuburbBoundary;
  circle?: { centre: Coordinate; radius: number };
  routeGeoJson?: GeoJSON.Feature<GeoJSON.LineString, object>;
  selectedPoint?: CustomMapPoint;
};

export default function CustomMap(props: CustomMapProps) {
  return (
    <MapContainer
      center={
        props.centre
          ? [props.centre.lat, props.centre.long]
          : [-33.856758, 151.215295]
      }
      zoom={props.zoom || 12}
      scrollWheelZoom={props.scrollWheelZoom || false}
      style={{
        height: props.height || "50vh",
        width: props.width || "100%",
        zIndex: 1,
      }}
    >
      <CustomMapContent
        points={props.points}
        clickToPlaceMarker={props.clickToPlaceMarker}
        onMarkerPlaced={props.onMarkerPlaced}
        markerPosition={props.markerPosition}
        suburbBoundary={props.suburbBoundary}
        circle={props.circle}
        routeGeoJson={props.routeGeoJson}
        selectedPoint={props.selectedPoint}
      />
    </MapContainer>
  );
}
