import dayjs from "dayjs";
import { TimePeriod } from "../models/TimePeriod";

// Function to get the start and end date for the selected time period
export const getDateRangeForPeriod = (
  timePeriod: TimePeriod
): { startDate: Date; endDate: Date } => {
  const now = dayjs();
  let startDate, endDate;

  switch (timePeriod) {
    case TimePeriod.Last30Days:
      startDate = now.subtract(30, "days").toDate();
      endDate = now.toDate();
      break;
    case TimePeriod.Last3Months:
      startDate = now.subtract(3, "month").toDate();
      endDate = now.toDate();
      break;
    case TimePeriod.Last6Months:
      startDate = now.subtract(6, "month").toDate();
      endDate = now.toDate();
      break;
    case TimePeriod.LastYear:
      startDate = now.subtract(1, "year").toDate();
      endDate = now.toDate();
      break;
    default:
      throw new Error("Invalid time period");
  }

  return { startDate, endDate };
};
