export type Path<T> = T extends object
  ? {
      [K in keyof T]: T[K] extends Array<infer U>
        ? `${K & string}[${number}]` | `${K & string}[${number}].${Path<U>}`
        : T[K] extends object
        ? `${K & string}` | `${K & string}.${Path<T[K]>}`
        : `${K & string}`;
    }[keyof T]
  : never;

export type ColumnType<T> = {
  label: string;
  accessor: Path<T>;
  width?: string | number;
  formatter?: (value: T) => string;
};

type NestedValue<T, P extends string> = P extends `${infer K}.${infer Rest}`
  ? K extends keyof T
    ? NestedValue<T[K], Rest>
    : never
  : P extends `${infer K}[${number}]`
  ? K extends keyof T
    ? T[K] extends Array<infer U>
      ? U
      : never
    : never
  : P extends keyof T
  ? T[P]
  : never;

export function GetNestedValue<T, P extends Path<T>>(
  obj: T,
  path: P
): NestedValue<T, P> {
  return path.split(".").reduce((value, key) => {
    const arrayMatch = key.match(/^(\w+)\[(\d+)\]$/);

    if (arrayMatch) {
      const arrayKey = arrayMatch[1];
      const arrayIndex = parseInt(arrayMatch[2], 10);

      const arrayValue = (value as Record<string, unknown>)[arrayKey];
      return Array.isArray(arrayValue) ? arrayValue[arrayIndex] : undefined;
    } else {
      return (value as Record<string, unknown>)[key];
    }
  }, obj as unknown) as NestedValue<T, P>;
}
